@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -92,7 +103,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 		newbt1.atmi[1] = local_ind2;		// this is a local index...
 		
 		bool success = false;
-		if (dynamic_cast<setup1_mm *>(GetSetup())->EnableExceptions())
+		if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
 		{
 			i32s bt = bndtab[n1]->bt.GetValue();
 			
@@ -169,7 +180,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 				newbt2.atmi[1] = bt1_vector[(* ita).bndr->tmp_bt1_index].get_atmi(0, dir[0]);
 				
 				bool success = false;
-				if (dynamic_cast<setup1_mm *>(GetSetup())->EnableExceptions())
+				if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
 				{
 					i32s bt[2];
 					bt[0] = (* ita).bndr->bt.GetValue();
@@ -335,7 +346,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 	iter_bl itb3 = find(GetSetup()->GetModel()->GetBondsBegin(), GetSetup()->GetModel()->GetBondsEnd(), tmpb3);
 					
 					bool success = false;
-					if (dynamic_cast<setup1_mm *>(GetSetup())->EnableExceptions())
+					if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
 					{
 						i32s bt[3];
 						bt[0] = (* itb1).bt.GetValue();
@@ -467,7 +478,7 @@ if (!GetSetup()->GetModel()->IsIndexClean())	// obsolete???
 if (newbt4.atmi[1] != n1) { cout << "OOPS THIS IS NOT WORKING!!!" << endl; exit(EXIT_FAILURE); }
 			
 			bool success = false;
-			if (dynamic_cast<setup1_mm *>(GetSetup())->EnableExceptions())
+			if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
 			{
 				i32s bt[3];
 				bt[0] = crtab[(n2 + 0) % 3]->bndr->bt.GetValue();
@@ -1171,7 +1182,7 @@ eng1_mm_default_nbt_bp::eng1_mm_default_nbt_bp(setup * p1, i32u p2) :
 				newnbt1.atmi[1] = ind2;		// this is a local index...
 				
 				bool success = false;
-				if (dynamic_cast<setup1_mm *>(GetSetup())->EnableExceptions())
+				if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
 				{
 					success = default_tables::GetInstance()->e_Init(this, & newnbt1, is14);
 				}
@@ -1732,7 +1743,7 @@ void eng1_mm_default_nbt_mim::UpdateTerms(void)
 				newnbt1.atmi[1] = ind2;
 				
 				bool success = false;
-				if (dynamic_cast<setup1_mm *>(GetSetup())->EnableExceptions())
+				if (dynamic_cast<setup1_mm *>(GetSetup())->GetExceptions())
 				{
 					success = default_tables::GetInstance()->e_Init(this, & newnbt1, is14);
 				}
