@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen, Geoff Hutchison.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -12,8 +23,8 @@
 
 #include "v3d.h"
 
-#include <string.h>
-
+//#include <string.h>
+#include <cstring>	// required by gcc-4.3
 #include <iomanip>
 #include <iostream>
 #include <sstream>
@@ -335,7 +346,7 @@ void sequencebuilder::Build(model * mdl, sb_chain_descriptor * chde, bool do_cen
 			
 			newatom.formal_charge = main_vector[n2].f_chrg;
 			
-			mdl->AddAtom(newatom);
+			mdl->AddAtom_lg(newatom);
 			atom_vector.push_back(& mdl->GetLastAtom());
 			allatm_vector.push_back(& mdl->GetLastAtom());
 			
@@ -364,7 +375,7 @@ void sequencebuilder::Build(model * mdl, sb_chain_descriptor * chde, bool do_cen
 				
 				newatom.formal_charge = conn_vector[n2].f_chrg;
 				
-				mdl->AddAtom(newatom);
+				mdl->AddAtom_lg(newatom);
 				atom_vector.push_back(& mdl->GetLastAtom());
 				allatm_vector.push_back(& mdl->GetLastAtom());
 				
@@ -1052,7 +1063,7 @@ void sequencebuilder::BuildResidue(sb_chain_descriptor * chde, model * mdl, sb_d
 		
 		newatom.formal_charge = res->atm_vector[n1].f_chrg;
 		
-		mdl->AddAtom(newatom);
+		mdl->AddAtom_lg(newatom);
 		atom_vector.push_back(& mdl->GetLastAtom());
 		allatm_vector.push_back(& mdl->GetLastAtom());
 		
