@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -13,6 +24,7 @@
 #include "typerule.h"
 #include "utility.h"
 
+#include <cstring>	// required by gcc-4.3
 #include <iomanip>
 #include <fstream>
 #include <sstream>
@@ -226,7 +238,7 @@ i32u prmfit_tables::UpdateTypes(setup * su)
 	if (mdl->verbosity >= 3)
 	{
 		ostringstream str;
-		str << "Setting up atom types and formal charges..." << NEWLINE << ends;
+		str << "Setting up atom types and formal charges..." << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
@@ -278,7 +290,7 @@ i32u prmfit_tables::UpdateTypes(setup * su)
 			if (mdl->verbosity >= 2)
 			{
 				ostringstream str;
-				str << "WARNING : could not determine atomtype (atom index = " << (* it1).index << ")." << NEWLINE << ends;
+				str << "WARNING : could not determine atomtype (atom index = " << (* it1).index << ")." << endl << ends;
 				
 				mdl->PrintToLog(str.str().c_str());
 			}
@@ -301,7 +313,7 @@ i32u prmfit_tables::UpdateCharges(setup * su)
 	if (mdl->verbosity >= 3)
 	{
 		ostringstream str;
-		str << "Setting up partial charges..." << NEWLINE << ends;
+		str << "Setting up partial charges..." << endl << ends;
 		mdl->PrintToLog(str.str().c_str());
 	}
 	
@@ -390,7 +402,7 @@ void prmfit_tables::DoParamSearch(prmfit_bs_query * query, model * mdl)
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[0] << dec << " ";
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[1] << dec << " ";
 		str << query->bndtp.GetValue() << " ";
-		str << NEWLINE << ends;
+		str << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
@@ -470,7 +482,7 @@ void prmfit_tables::DoParamSearch(prmfit_ab_query * query, model * mdl)
 		str << "0x" << hex << setw(4) << setfill('0') << query->atmtp[2] << dec << " ";
 		str << query->bndtp[0].GetValue() << " ";
 		str << query->bndtp[1].GetValue() << " ";
-		str << NEWLINE << ends;
+		str << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
@@ -555,7 +567,7 @@ void prmfit_tables::DoParamSearch(prmfit_tr_query * query, model * mdl)
 		str << query->bndtp[0].GetValue() << " ";
 		str << query->bndtp[1].GetValue() << " ";
 		str << query->bndtp[2].GetValue() << " ";
-		str << NEWLINE << ends;
+		str << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
@@ -652,7 +664,7 @@ void prmfit_tables::DoParamSearch(prmfit_op_query * query, model * mdl)
 		str << query->bndtp[0].GetValue() << " ";
 		str << query->bndtp[1].GetValue() << " ";
 		str << query->bndtp[2].GetValue() << " ";
-		str << NEWLINE << ends;
+		str << endl << ends;
 		
 		mdl->PrintToLog(str.str().c_str());
 	}
